Ext.namespace('dSA', 'dSA.util');

dSA.util.shortDSID = function(dsid) {
    if (dsid.length > 8)
    {
        return dsid.slice(dsid.length - 8);
    }
    else
    {
        return dsid;
    }
};

dSA.util.getName = function(name) {
    if ((name === undefined) || (name.length === 0))
    {
        return '<i>' + dSA._("no name") + '</i>';
    }
    else
    {
        return name;
    }
};

dSA.util.getData = function(response)
{
    var json = Ext.util.JSON.decode(response.responseText);
    if (json.success === false)
    {
        throw json.message;
    }

    if (json.data === undefined)
    {
        throw dSA._("could not retrieve data from response");
    }
    return json.data;
};

dSA.util.checkResponse = function(response)
{
    var json = Ext.util.JSON.decode(response.responseText);
    if (json.success === false)
    {
        throw json.message;
    }
};

dSA.util.failureMessage = function(response)
{
    try
    {
        var json = Ext.util.JSON.decode(response.responseText);
        if (json.message)
        {
            return json.message;
        }
    }
    catch (error)
    {
        // when the dSA is not running lighttpds proxy will return an
        // HTTP 500 along with some HTML which will cause a JSON parsing error
        return "";
    }
};

dSA.util.colon = function(text)
{
    if ((text === undefined) || (String(text).length === 0))
    {
        return "";
    }

    return ": " + text;
};


// this function never fails
dSA.util.getNumDevices = function(dsid, callback)
{
    if (callback === undefined)
    {
        return;
    }

    Ext.Ajax.request({
        url: '/dsa/json/hardware/get',
        disableCaching: true,
        method: 'GET',
        params:
        {
            dsm: dsid
        },
        success: function(response, opts)
        {
            try
            {
                var data = dSA.util.getData(response);
                if ((data.dsms === undefined) && (data.dsms.length === 0))
                {
                    callback(0);
                }

                if (data.dsms[0].dsid === dsid) {
                    callback(data.dsms[0].devices.length);
                    return;
                }
            }
            catch (error)
            {}

            callback(0);
        },
        failure: function(response, opts)
        {
            callback(0);
        }
    });
};

dSA.util.unmask = function(maskEl)
{
    if (maskEl !== undefined)
    {
        maskEl.unmask();
    }
};

dSA.util.mask = function(maskEl, text)
{
    if (maskEl !== undefined)
    {
        maskEl.mask();
    }
};

dSA.util.ButtonInputParameters =
{
    "BUTTONINPUT_STANDARD"             : 0,
    "BUTTONINPUT_TURBO"                : 1,
    "BUTTONINPUT_SWITCH_STANDARD"      : 2,
    "BUTTONINPUT_SWITCH_EDGE"          : 3,
    "BUTTONINPUT_SWITCH_TIP"           : 4,
    "BUTTONINPUT_2WAY_DW_WITH_INPUT1"  : 5,
    "BUTTONINPUT_2WAY_DW_WITH_INPUT2"  : 6,
    "BUTTONINPUT_2WAY_DW_WITH_INPUT3"  : 7,
    "BUTTONINPUT_2WAY_DW_WITH_INPUT4"  : 8,
    "BUTTONINPUT_2WAY_UP_WITH_INPUT1"  : 9,
    "BUTTONINPUT_2WAY_UP_WITH_INPUT2"  : 10,
    "BUTTONINPUT_2WAY_UP_WITH_INPUT3"  : 11,
    "BUTTONINPUT_2WAY_UP_WITH_INPUT4"  : 12,
    "BUTTONINPUT_2WAY_UP_DOWN"         : 13,
    "BUTTONINPUT_SCENEDEVICE"          : 20
};

dSA.util.PushButtonModeToString = function(buttonMode, buttonIndex,
                                            buttonCount) {
    var dec = (buttonMode & 0x000000ff);
    var ret = "";

    switch (dec)
    {
        default:
        case dSA.util.ButtonInputParameters.BUTTONINPUT_STANDARD:
        case dSA.util.ButtonInputParameters.BUTTONINPUT_TURBO:
            break;
            break;
        case dSA.util.ButtonInputParameters.BUTTONINPUT_SWITCH_STANDARD:
        case dSA.util.ButtonInputParameters.BUTTONINPUT_SWITCH_EDGE:
        case dSA.util.ButtonInputParameters.BUTTONINPUT_SWITCH_TIP:
            ret = dSA._("Switch");
            break;
        case dSA.util.ButtonInputParameters.BUTTONINPUT_2WAY_UP_WITH_INPUT1:
        case dSA.util.ButtonInputParameters.BUTTONINPUT_2WAY_UP_WITH_INPUT2:
        case dSA.util.ButtonInputParameters.BUTTONINPUT_2WAY_UP_WITH_INPUT3:
        case dSA.util.ButtonInputParameters.BUTTONINPUT_2WAY_UP_WITH_INPUT4:
        case dSA.util.ButtonInputParameters.BUTTONINPUT_2WAY_UP_DOWN:
            ret = dSA._("2-Way up");
            break;
        case dSA.util.ButtonInputParameters.BUTTONINPUT_2WAY_DW_WITH_INPUT1:
        case dSA.util.ButtonInputParameters.BUTTONINPUT_2WAY_DW_WITH_INPUT2:
        case dSA.util.ButtonInputParameters.BUTTONINPUT_2WAY_DW_WITH_INPUT3:
        case dSA.util.ButtonInputParameters.BUTTONINPUT_2WAY_DW_WITH_INPUT4:
        case dSA.util.ButtonInputParameters.BUTTONINPUT_2WAY_UP_DOWN:
            ret = dSA._("2-Way down");
            break;
        case dSA.util.ButtonInputParameters.BUTTONINPUT_2WAY_UP_DOWN:
            ret = dSA._("2-Way");
            break;
        case dSA.util.ButtonInputParameters.BUTTONINPUT_SCENEDEVICE:
            ret = dSA._("Scene");
            break;
    }

    if (buttonCount > 1)
    {
        if(ret !==  "")
        {
            ret = dSA._("Line") + " " + (buttonIndex+1) + ", " + ret;
        }
        else
        {
            ret = dSA._("Line") + " " + (buttonIndex+1);
        }
    }

    return ret;
};

